@@ -1651,6 +1651,18 @@ VARCHAR;
 LPAD(tbl.bin_col, 10, 0x20);
 BINARY;
 
+# dialect: snowflake
+RPAD('Hello', 10, '*');
+VARCHAR;
+
+# dialect: snowflake
+RPAD(tbl.str_col, 10);
+VARCHAR;
+
+# dialect: snowflake
+RPAD(tbl.bin_col, 10, 0x20);
+BINARY;
+
 # dialect: snowflake
 COLLATION('hello');
 VARCHAR;
@@ -1799,6 +1811,34 @@ INT;
 LENGTH(tbl.bin_col);
 INT;
 
+# dialect: snowflake
+OCTET_LENGTH(tbl.str_col);
+INT;
+
+# dialect: snowflake
+OCTET_LENGTH(tbl.bin_col);
+INT;
+
+# dialect: snowflake
+PARSE_URL('https://example.com/path');
+OBJECT;
+
+# dialect: snowflake
+PARSE_URL(tbl.str_col, 0);
+OBJECT;
+
+# dialect: snowflake
+POSITION('abc' IN 'abcdef');
+INT;
+
+# dialect: snowflake
+POSITION('abc', 'abcdef');
+INT;
+
+# dialect: snowflake
+POSITION('abc', 'abcdef', 1);
+INT;
+
 # dialect: snowflake
 LOWER(tbl.str_col);
 VARCHAR;
@@ -1815,6 +1855,18 @@ VARCHAR;
 LTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+'foo' REGEXP 'bar';
+BOOLEAN;
+
+# dialect: snowflake
+'foo' NOT REGEXP 'bar';
+BOOLEAN;
+
+# dialect: snowflake
+'text123' REGEXP '^[a-z]+[0-9]+$';
+BOOLEAN;
+
 # dialect: snowflake
 REGEXP_LIKE('foo', 'bar');
 BOOLEAN;
@@ -1939,6 +1991,10 @@ VARCHAR;
 RTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+RTRIMMED_LENGTH(' ABCD ');
+INT;
+
 # dialect: snowflake
 SHA1('foo');
 VARCHAR;
@@ -2171,6 +2227,10 @@ BOOLEAN;
 ILIKE(tbl.str_col, 'pattern');
 BOOLEAN;
 
+# dialect: snowflake
+PARSE_IP('192.168.1.1', 'INET');
+OBJECT;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
